@@ -3,6 +3,7 @@ import logging
 
 from ming.utils import LazyProperty
 from ming.orm.ormsession import ThreadLocalORMSession
+from pylons import tmpl_context as c
 
 # Pyforge-specific imports
 import allura.tasks
@@ -11,6 +12,7 @@ from allura import model as M
 from allura.controllers.repository import RepoRootController, RefsController, CommitsController
 from allura.controllers.repository import MergeRequestsController, RepoRestController
 from allura.lib.repository import RepositoryApp
+from allura.app import SitemapEntry
 
 # Local imports
 from . import model as HM
@@ -30,7 +32,6 @@ class ForgeHgApp(RepositoryApp):
     """
     ordinal=3
     forkable=True
-    default_branch_name='default'
 
     def __init__(self, project, config):
         super(ForgeHgApp, self).__init__(project, config)
@@ -44,6 +45,23 @@ class ForgeHgApp(RepositoryApp):
     def repo(self):
         return HM.Repository.query.get(app_config_id=self.config._id)
 
+    @property
+    def default_branch_name(self):
+        default_branch_name = getattr(self.repo, 'default_branch_name', 'default')
+        if not default_branch_name:
+            default_branch_name = 'default'
+        return default_branch_name
+
+
+    def admin_menu(self):
+        links = []
+        links.append(SitemapEntry(
+                'Set default branch',
+                c.project.url()+'admin/'+self.config.options.mount_point+'/' + 'set_default_branch_name',
+                className='admin_modal'))
+        links += super(ForgeHgApp, self).admin_menu()
+        return links
+
     def install(self, project):
         '''Create repo object for this tool'''
         super(ForgeHgApp, self).install(project)
