@@ -373,4 +373,9 @@ class HgImplementation(M.RepositoryImplementation):
     def tags(self):
         return [Object(name=k, object_id=self._hg[v].hex()) for k,v in self._hg.tags().items()]
 
+    def set_default_branch(self, name):
+        if not name:
+            return
+        self._repo.default_branch_name = name
+
 Mapper.compile_all()
